import Redis, { Cluster } from 'ioredis';
import { AsyncReturnType } from './type';
import { ErrorHandler } from './utils';
import { Stat } from './stat';
import { KeyStringer } from './keyStringer';
export declare const notFoundPlaceholder = "*";
export declare type IsNotFound = (val: any) => boolean;
export interface Option {
    redis: Redis | Cluster;
    prefix: string;
    codec?: string;
    withPrometheus?: boolean;
    notFoundExpire?: number;
    isNOtFound?: IsNotFound;
    name?: string;
}
export interface Cacher {
    cacheFn<F extends () => Promise<unknown>>(key: string, fn: F, expire: number, codec?: string, thisArg?: ThisParameterType<F>): Promise<AsyncReturnType<F>>;
    cacheWrapper<T extends (...args: any[]) => Promise<any>>(keyPrefix: string, fn: T, expire: number, codec?: string, keyStringer?: KeyStringer, thisArg?: ThisParameterType<T>): T;
    deleteFnCache(keyPrefix: string, args: any[], keyStringer?: KeyStringer): Promise<void>;
    get<T = any>(key: string, codec?: string): Promise<[T, boolean]>;
    set<T = any>(key: string, val: T, expire: number, codec?: string): Promise<void>;
    delete(...keys: string[]): Promise<void>;
    clean(match?: string, count?: number): Promise<void>;
}
export declare class RedisCache implements Cacher {
    private readonly option;
    onError: ErrorHandler;
    private readonly sf;
    private stat;
    constructor(option: Option);
    cacheFn<F extends () => Promise<unknown>>(key: string, fn: F, expire: number, codec?: string, thisArg?: ThisParameterType<F>): Promise<AsyncReturnType<F>>;
    cacheWrapper<T extends (...args: any[]) => Promise<any>>(keyPrefix: string, fn: T, expire: number, codec?: string, keyStringer?: KeyStringer, thisArg?: ThisParameterType<T>): T;
    deleteFnCache(keyPrefix: string, args: any[], keyStringer?: KeyStringer): Promise<void>;
    /**
     * get data from cache
     * @param key
     * @param codec
     * @returns [val, isNotFound]
     */
    get<T = any>(key: string, codec?: string): Promise<[T, boolean]>;
    set<T = any>(key: string, val: T, expire: number, codec?: string): Promise<void>;
    delete(...keys: string[]): Promise<void>;
    clean(match?: string, count?: number): Promise<void>;
    getStat(): Stat;
    resetStat(): void;
    private buildKey;
    private getCodecByName;
    private setupPrometheus;
    private incrRequestsCounter;
    private incrHitCounter;
    private incrErrorsCounter;
    private incrHitNotFoundCacheCounter;
    private incrCounter;
    static joinKey(...keys: string[]): string;
}
