"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.combineKeyStringer = exports.md5KeyStringer = void 0;
const crypto_1 = require("crypto");
const maxKeyLen = 200;
const md5KeyStringer = (...args) => {
    if (args.length === 0) {
        return '';
    }
    return (0, crypto_1.createHash)('md5').update(JSON.stringify(args)).digest('hex');
};
exports.md5KeyStringer = md5KeyStringer;
const isSimpleType = (v) => {
    return ['string', 'number', 'boolean'].includes(typeof v);
};
/**
 * combineKeyStringer will use origin args (array.join) to build the key when
 *   1. all args is simple type [string, number, boolean]
 *   2. output key length less than 200
 * otherwise it will fallback to md5KeyStringer
 */
const combineKeyStringer = (...args) => {
    if (args.some((v) => !isSimpleType(v))) {
        return (0, exports.md5KeyStringer)(...args);
    }
    const key = args.join('|');
    if (key.length > maxKeyLen) {
        return (0, exports.md5KeyStringer)(...args);
    }
    return key;
};
exports.combineKeyStringer = combineKeyStringer;
//# sourceMappingURL=keyStringer.js.map