"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ShardingCache = void 0;
const hashring_1 = __importDefault(require("hashring"));
const cache_1 = require("./cache");
const utils_1 = require("./utils");
const keyStringer_1 = require("./keyStringer");
class ShardingCache {
    constructor(option) {
        this.nodeMap = new Map();
        const servers = {};
        for (const node of option.nodes) {
            this.nodeMap.set(node.key, node.redisCache);
            servers[node.key] = { weight: node.weight };
        }
        this.ring = new hashring_1.default(servers);
    }
    async cacheFn(key, fn, expire, codec, thisArg) {
        const node = this.pickNode(key);
        return node.cacheFn(key, fn, expire, codec, thisArg);
    }
    cacheWrapper(keyPrefix, fn, expire, codec, keyStringer = keyStringer_1.combineKeyStringer, thisArg) {
        return ((...args) => {
            const cacheKey = cache_1.RedisCache.joinKey(keyPrefix, keyStringer(...args));
            return this.cacheFn(cacheKey, () => (0, utils_1.bindThis)(fn, thisArg)(...args), expire, codec);
        });
    }
    async deleteFnCache(keyPrefix, args, keyStringer = keyStringer_1.combineKeyStringer) {
        const cacheKey = cache_1.RedisCache.joinKey(keyPrefix, keyStringer(...args));
        await this.delete(cacheKey);
    }
    async get(key, codec) {
        const node = this.pickNode(key);
        return node.get(key, codec);
    }
    async set(key, val, expire, codec) {
        const node = this.pickNode(key);
        await node.set(key, val, expire, codec);
    }
    async delete(...keys) {
        await Promise.all(keys.map((key) => {
            const node = this.pickNode(key);
            return node.delete(key);
        }));
    }
    async clean(match = '*', count = 100) {
        await Promise.all([...this.nodeMap.values()].map((node) => node.clean(match, count)));
    }
    pickNode(key) {
        const nodeKey = this.ring.get(key);
        (0, utils_1.debug)(`pick node, key: ${key}, nodeKey: ${nodeKey}`);
        return this.nodeMap.get(nodeKey);
    }
}
exports.ShardingCache = ShardingCache;
//# sourceMappingURL=sharding.js.map