"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.noopHandler = exports.bindThis = exports.redisScanDel = exports.debug = exports.loadPackage = void 0;
const debug_1 = require("debug");
/* c8 ignore next 2 */
const MISSING_REQUIRED_DEPENDENCY = (name, reason) => `The "${name}" package is missing. Please, make sure to install this library ($ npm install ${name}) to take advantage of ${reason}.`;
const loadPackage = (packageName, context, loaderFn) => {
    try {
        return loaderFn ? loaderFn() : require(packageName);
        /* c8 ignore next 4 */
    }
    catch (e) {
        console.error(MISSING_REQUIRED_DEPENDENCY(packageName, context));
        process.exit(1);
    }
};
exports.loadPackage = loadPackage;
exports.debug = (0, debug_1.debug)('node-redis-cache');
const redisScanDel = async (redis, match, count) => {
    return new Promise((resolve, reject) => {
        const stream = redis.scanStream({
            match,
            count,
        });
        stream.on('data', (keys = []) => {
            if (!keys.length) {
                return;
            }
            stream.pause();
            (0, exports.debug)('redisScanDel delete keys: ', keys);
            // redis.del(keys) will fail in cluster mode
            Promise.all(keys.map((key) => redis.del(key)))
                .then(() => {
                stream.resume();
            })
                /* c8 ignore next 6 */
                .catch((err) => {
                err.match = match;
                return reject(err);
            });
        });
        /* c8 ignore next 3 */
        stream.on('error', (err) => {
            reject(err);
        });
        stream.on('end', () => {
            resolve();
        });
    });
};
exports.redisScanDel = redisScanDel;
const bindThis = (fn, thisArg) => {
    return thisArg == null ? fn : fn.bind(thisArg);
};
exports.bindThis = bindThis;
const noopHandler = () => { };
exports.noopHandler = noopHandler;
//# sourceMappingURL=utils.js.map